Crate mpl_candy_machine_core

Crate mpl_candy_machine_core 

Re-exports

pub use errors::CandyError;

Modules

accounts
An Anchor generated module, providing a set of structs mirroring the structs deriving Accounts, where each field is a Pubkey. This is useful for specifying accounts for a client.
candy_machine
candy_machine_core
candy_machine_data
constants
errors
instruction
An Anchor generated module containing the program’s set of instructions, where each method handler in the #[program] mod is associated with a struct defining the input arguments to the method. These should be used directly, when one wants to serialize Anchor instruction data, for example, when speciying instructions on a client.
program
Module representing the program.

Structs

ApproveCollectionAuthorityHelperAccounts
ApproveMetadataDelegateHelperAccounts
AssociatedToken
Anchor wrapper for Associated Token program.
CandyMachine
Candy machine state and config data.
CandyMachineData
Candy machine configuration data.
ConfigLine
Config line struct for storing asset (NFT) data pre-mint.
ConfigLineSettings
Config line settings to allocate space for individual name + URI.
Creator
HiddenSettings
Hidden settings for large mints used with off-chain data.
RevokeCollectionAuthorityHelperAccounts
RevokeMetadataDelegateHelperAccounts
Token
Anchor wrapper for Token program.

Enums

AccountVersion
Account versioning.

Statics

ID
The static program ID

Functions

approve_collection_authority_helper
approve_metadata_delegate
assert_edition_from_mint
assert_initialized
assert_token_standard
check_id
Confirms that a given pubkey is equivalent to the program ID
cmp_pubkeys
entry
The Anchor codegen exposes a programming model where a user defines a set of methods inside of a #[program] module in a way similar to writing RPC request handlers. The macro then generates a bunch of code wrapping these user defined methods into something that can be executed on Solana.
entrypoint
Safety
fixed_length_string
Return a padded string up to the specified length. If the specified string value is longer than the allowed length, return an error.
get_config_count
Return the current number of lines written to the account.
id
Returns the program ID
replace_patterns
Replace the index pattern variables on the specified string.
revoke_collection_authority_helper
revoke_metadata_delegate