pub struct SetTokenStandard {
pub token_standard: u8,
}Expand description
Instruction.
Fields
token_standard: u8Trait Implementations
sourceimpl BorshDeserialize for SetTokenStandardwhere
u8: BorshDeserialize,
impl BorshDeserialize for SetTokenStandardwhere
u8: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
sourceimpl BorshSerialize for SetTokenStandardwhere
u8: BorshSerialize,
impl BorshSerialize for SetTokenStandardwhere
u8: BorshSerialize,
sourceimpl Discriminator for SetTokenStandard
impl Discriminator for SetTokenStandard
const DISCRIMINATOR: [u8; 8] = _
fn discriminator() -> [u8; 8]
sourceimpl InstructionData for SetTokenStandard
impl InstructionData for SetTokenStandard