pub struct ConfigLineSettings {
pub prefix_name: String,
pub name_length: u32,
pub prefix_uri: String,
pub uri_length: u32,
pub is_sequential: bool,
}Expand description
Config line settings to allocate space for individual name + URI.
Fields
prefix_name: StringCommon name prefix
name_length: u32Length of the remaining part of the name
prefix_uri: StringCommon URI prefix
uri_length: u32Length of the remaining part of the URI
is_sequential: boolIndicates whether to use a senquential index generator or not