Re-exports
pub use errors::CandyError;
Modules
- accounts
- An Anchor generated module, providing a set of structs
mirroring the structs deriving
Accounts, where each field is aPubkey. This is useful for specifying accounts for a client. - candy_
machine - candy_
machine_ core - candy_
machine_ data - constants
- errors
- instruction
- An Anchor generated module containing the program’s set of
instructions, where each method handler in the
#[program]mod is associated with a struct defining the input arguments to the method. These should be used directly, when one wants to serialize Anchor instruction data, for example, when speciying instructions on a client. - program
- Module representing the program.
Structs
- Approve
Collection Authority Helper Accounts - Approve
Metadata Delegate Helper Accounts - Associated
Token - Anchor wrapper for Associated Token program.
- Candy
Machine - Candy machine state and config data.
- Candy
Machine Data - Candy machine configuration data.
- Config
Line - Config line struct for storing asset (NFT) data pre-mint.
- Config
Line Settings - Config line settings to allocate space for individual name + URI.
- Creator
- Hidden
Settings - Hidden settings for large mints used with off-chain data.
- Revoke
Collection Authority Helper Accounts - Revoke
Metadata Delegate Helper Accounts - Token
- Anchor wrapper for Token program.
Enums
- Account
Version - Account versioning.
Statics
- ID
- The static program ID
Functions
- approve_
collection_ authority_ helper - approve_
metadata_ delegate - assert_
edition_ from_ mint - assert_
initialized - assert_
token_ standard - check_
id - Confirms that a given pubkey is equivalent to the program ID
- cmp_
pubkeys - entry
- The Anchor codegen exposes a programming model where a user defines
a set of methods inside of a
#[program]module in a way similar to writing RPC request handlers. The macro then generates a bunch of code wrapping these user defined methods into something that can be executed on Solana. - entrypoint⚠
- Safety
- fixed_
length_ string - Return a padded string up to the specified length. If the specified
string
valueis longer than the allowedlength, return an error. - get_
config_ count - Return the current number of lines written to the account.
- id
- Returns the program ID
- replace_
patterns - Replace the index pattern variables on the specified string.
- revoke_
collection_ authority_ helper - revoke_
metadata_ delegate